.. report

report
------

.. automodule:: pvfactors.report
   :no-members:
   :no-inherited-members:
   :noindex:

.. autosummary::
   :toctree: generated/
   :nosignatures:

   ~pvfactors.report.example_fn_build_report
   ~pvfactors.report.ExampleReportBuilder
